@@ -209,8 +209,8 @@ class SagemakerFeatureStore:
         enable_online_store: bool,
         online_store_sources: List[str],
         enable_offline_store: bool,
-        description: str,
-        tags: List[Dict[str, str]],
+        description: str = None,
+        tags: List[Dict[str, str]] = None,
         s3_uri_offline_store_output: str = None,
     ):
         """
@@ -280,8 +280,14 @@ class SagemakerFeatureStore:
                 + "Must include: [{'type': 'real-time/batch'}, {'schedule': 'event-based/daily/5m/6h'}, {'storage': 'online-only/online-offline/offline'}]"
             )
         else:
+            # Fix formatting
+            new_tags = []
+            for tag in tags:
+                for key, value in tag.items():
+                    new_tags.append({"Key": key, "Value": value})
             if "redis" in online_store_sources:
                 tags.append({"online-store": "redis"})
+                new_tags.append({"Key": "online-store", "Value": "redis"})
 
         # Feature group creation
         feature_group.create(
@@ -293,7 +299,7 @@ class SagemakerFeatureStore:
             role_arn=self.role,
             enable_online_store=enable_online_store,
             description=description,
-            tags=tags,
+            tags=new_tags,
         )
 
         print(f'Creating "{feature_group_name}" Feature Group..')
@@ -323,6 +329,8 @@ class SagemakerFeatureStore:
             "enable_offline_store": enable_offline_store,
             "s3_uri_offline_store_output": s3_uri_offline_store_output,
             "feature_registry_path": feature_registry_s3,
+            "description": description,
+            "tags": tags,
         }
 
         s3 = boto3.resource("s3")
